@@ -2,10 +2,9 @@
 `contextily`: create context with map tiles in Python
 """
 
-from . import tile_providers as sources
-from ._providers import providers
+import xyzservices.providers as providers
 from .place import Place, plot_map
 from .tile import *
 from .plotting import add_basemap, add_attribution
 
-__version__ = "1.0.1"
+__version__ = "1.2.0"
