@@ -2,9 +2,8 @@
 
 import warnings
 import numpy as np
-from . import tile_providers as sources
 from . import providers
-from ._providers import TileProvider
+from xyzservices import TileProvider
 from .tile import bounds2img, _sm2ll, warp_tiles, _warper
 from rasterio.enums import Resampling
 from rasterio.warp import transform_bounds
@@ -26,7 +25,6 @@ def add_basemap(
     reset_extent=True,
     crs=None,
     resampling=Resampling.bilinear,
-    url=None,
     **extra_imshow_args
 ):
     """
@@ -41,10 +39,10 @@ def add_basemap(
     zoom : int or 'auto'
         [Optional. Default='auto'] Level of detail for the basemap. If 'auto',
         it is calculated automatically. Ignored if `source` is a local file.
-    source : contextily.providers object or str
+    source : xyzservices.TileProvider object or str
         [Optional. Default: Stamen Terrain web tiles]
         The tile source: web tile provider or path to local file. The web tile
-        provider can be in the form of a `contextily.providers` object or a
+        provider can be in the form of a :class:`xyzservices.TileProvider` object or a
         URL. The placeholders for the XYZ in the URL need to be `{x}`, `{y}`,
         `{z}`, respectively. For local file paths, the file is read with
         `rasterio` and all bands are loaded into the basemap.
@@ -76,11 +74,6 @@ def add_basemap(
         [Optional. Default=Resampling.bilinear] Resampling
         method for executing warping, expressed as a
         `rasterio.enums.Resampling` method
-    url : str [DEPRECATED]
-        [Optional. Default: 'http://tile.stamen.com/terrain/{z}/{x}/{y}.png']
-        Source url for web tiles, or path to local file. If
-        local, the file is read with `rasterio` and all
-        bands are loaded into the basemap.
     **extra_imshow_args :
         Other parameters to be passed to `imshow`.
 
@@ -111,21 +104,6 @@ def add_basemap(
 
     """
     xmin, xmax, ymin, ymax = ax.axis()
-    if url is not None and source is None:
-        warnings.warn(
-            'The "url" option is deprecated. Please use the "source"'
-            " argument instead.",
-            FutureWarning,
-            stacklevel=2,
-        )
-        source = url
-    elif url is not None and source is not None:
-        warnings.warn(
-            'The "url" argument is deprecated. Please use the "source"'
-            ' argument. Do not supply a "url" argument. It will be ignored.',
-            FutureWarning,
-            stacklevel=2,
-        )
     # If web source
     if (
         source is None
@@ -146,6 +124,10 @@ def add_basemap(
         # Warping
         if crs is not None:
             image, extent = warp_tiles(image, extent, t_crs=crs, resampling=resampling)
+        # Check if overlay
+        if _is_overlay(source) and 'zorder' not in extra_imshow_args:
+            # If zorder was not set then make it 9 otherwise leave it
+            extra_imshow_args['zorder'] = 9
     # If local source
     else:
         import rasterio as rio
@@ -183,7 +165,7 @@ def add_basemap(
                 image = np.array([band for band in raster.read()])
                 img_transform = raster.transform
                 bb = raster.bounds
-                extent = bb.left, bb.right, bb.bottom, bb.top 
+                extent = bb.left, bb.right, bb.bottom, bb.top
             # Warp
             if (crs is not None) and (raster.crs != crs):
                 image, bounds, _ = _warper(
@@ -225,6 +207,44 @@ def _reproj_bb(left, right, bottom, top, s_crs, t_crs):
     n_l, n_b, n_r, n_t = transform_bounds(s_crs, t_crs, left, bottom, right, top)
     return n_l, n_r, n_b, n_t
 
+def _is_overlay(source):
+    """
+    Check if the identified source is an overlay (partially transparent) layer.
+
+    Parameters
+    ----------
+    source : dict
+        The tile source: web tile provider.  Must be preprocessed as
+        into a dictionary, not just a string.
+
+    Returns
+    -------
+    bool
+
+    Notes
+    -----
+    This function is based on a very similar javascript version found in leaflet:
+    https://github.com/leaflet-extras/leaflet-providers/blob/9eb968f8442ea492626c9c8f0dac8ede484e6905/preview/preview.js#L56-L70
+    """
+    if not isinstance(source, dict):
+        return False
+    if source.get('opacity', 1.0) < 1.0:
+        return True
+    overlayPatterns = [
+        '^(OpenWeatherMap|OpenSeaMap)',
+        'OpenMapSurfer.(Hybrid|AdminBounds|ContourLines|Hillshade|ElementsAtRisk)',
+        'Stamen.Toner(Hybrid|Lines|Labels)',
+        'CartoDB.(Positron|DarkMatter|Voyager)OnlyLabels',
+        'Hydda.RoadsAndLabels',
+        '^JusticeMap',
+        'OpenPtMap',
+        'OpenRailwayMap',
+        'OpenFireMap',
+        'SafeCast'
+    ]
+    import re
+    return bool(re.match('(' + '|'.join(overlayPatterns) + ')', source.get('name', '')))
+
 
 def add_attribution(ax, text, font_size=ATTRIBUTION_SIZE, **kwargs):
     """
